@@ -10,20 +10,23 @@ class Session():
     This class will manage a HTTP session to the tamin.ir API
     """
 
-    def __init__(self, oauth_token=None, url=None, username=None, password=None):
+    def __init__(self, oauth_token=None, url=None, username=None, password=None, need_token=True):
         self.session = requests.Session()
-        if url:
+        if url is not None:
             self.url = url
         else:
-            self.url = 'https://ep-test.tamin.ir/api/'
-        if not oauth_token:
-            oauth_token = self._login(username, password)
 
-        # Set default headers
-        default_headers = {
-            'Authorization': f'Bearer {oauth_token}',
-        }
-        self.session.headers.update(default_headers)
+            self.url = 'https://ep-test.tamin.ir/api/'
+        print(self.url)
+        if need_token:
+            if not oauth_token:
+                oauth_token = self._login(username, password)
+
+            # Set default headers
+            default_headers = {
+                'Authorization': f'Bearer {oauth_token}',
+            }
+            self.session.headers.update(default_headers)
 
     def _login(self, user, password):
         json_data = {
